@@ -105,95 +105,54 @@ CancelJobRunResponseTypeDef = TypedDict(
 CertificateTypeDef = TypedDict(
     "CertificateTypeDef",
     {
-        "certificateArn": str,
-        "certificateData": str,
+        "certificateArn": NotRequired[str],
+        "certificateData": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredCloudWatchMonitoringConfigurationTypeDef = TypedDict(
-    "_RequiredCloudWatchMonitoringConfigurationTypeDef",
+CloudWatchMonitoringConfigurationTypeDef = TypedDict(
+    "CloudWatchMonitoringConfigurationTypeDef",
     {
         "logGroupName": str,
+        "logStreamNamePrefix": NotRequired[str],
     },
 )
-_OptionalCloudWatchMonitoringConfigurationTypeDef = TypedDict(
-    "_OptionalCloudWatchMonitoringConfigurationTypeDef",
-    {
-        "logStreamNamePrefix": str,
-    },
-    total=False,
-)
-
-
-class CloudWatchMonitoringConfigurationTypeDef(
-    _RequiredCloudWatchMonitoringConfigurationTypeDef,
-    _OptionalCloudWatchMonitoringConfigurationTypeDef,
-):
-    pass
-
 
 ConfigurationOverridesTypeDef = TypedDict(
     "ConfigurationOverridesTypeDef",
     {
-        "applicationConfiguration": Sequence["ConfigurationTypeDef"],
-        "monitoringConfiguration": "MonitoringConfigurationTypeDef",
+        "applicationConfiguration": NotRequired[Sequence["ConfigurationTypeDef"]],
+        "monitoringConfiguration": NotRequired["MonitoringConfigurationTypeDef"],
     },
-    total=False,
 )
 
-_RequiredConfigurationTypeDef = TypedDict(
-    "_RequiredConfigurationTypeDef",
+ConfigurationTypeDef = TypedDict(
+    "ConfigurationTypeDef",
     {
         "classification": str,
+        "properties": NotRequired[Mapping[str, str]],
+        "configurations": NotRequired[Sequence[Dict[str, Any]]],
     },
 )
-_OptionalConfigurationTypeDef = TypedDict(
-    "_OptionalConfigurationTypeDef",
-    {
-        "properties": Mapping[str, str],
-        "configurations": Sequence[Dict[str, Any]],
-    },
-    total=False,
-)
-
-
-class ConfigurationTypeDef(_RequiredConfigurationTypeDef, _OptionalConfigurationTypeDef):
-    pass
-
 
 ContainerInfoTypeDef = TypedDict(
     "ContainerInfoTypeDef",
     {
-        "eksInfo": "EksInfoTypeDef",
+        "eksInfo": NotRequired["EksInfoTypeDef"],
     },
-    total=False,
 )
 
-_RequiredContainerProviderTypeDef = TypedDict(
-    "_RequiredContainerProviderTypeDef",
+ContainerProviderTypeDef = TypedDict(
+    "ContainerProviderTypeDef",
     {
         "type": Literal["EKS"],
         "id": str,
+        "info": NotRequired["ContainerInfoTypeDef"],
     },
 )
-_OptionalContainerProviderTypeDef = TypedDict(
-    "_OptionalContainerProviderTypeDef",
-    {
-        "info": "ContainerInfoTypeDef",
-    },
-    total=False,
-)
 
-
-class ContainerProviderTypeDef(
-    _RequiredContainerProviderTypeDef, _OptionalContainerProviderTypeDef
-):
-    pass
-
-
-_RequiredCreateManagedEndpointRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateManagedEndpointRequestRequestTypeDef",
+CreateManagedEndpointRequestRequestTypeDef = TypedDict(
+    "CreateManagedEndpointRequestRequestTypeDef",
     {
         "name": str,
         "virtualClusterId": str,
@@ -201,25 +160,11 @@ _RequiredCreateManagedEndpointRequestRequestTypeDef = TypedDict(
         "releaseLabel": str,
         "executionRoleArn": str,
         "clientToken": str,
+        "certificateArn": NotRequired[str],
+        "configurationOverrides": NotRequired["ConfigurationOverridesTypeDef"],
+        "tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalCreateManagedEndpointRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateManagedEndpointRequestRequestTypeDef",
-    {
-        "certificateArn": str,
-        "configurationOverrides": "ConfigurationOverridesTypeDef",
-        "tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateManagedEndpointRequestRequestTypeDef(
-    _RequiredCreateManagedEndpointRequestRequestTypeDef,
-    _OptionalCreateManagedEndpointRequestRequestTypeDef,
-):
-    pass
-
 
 CreateManagedEndpointResponseTypeDef = TypedDict(
     "CreateManagedEndpointResponseTypeDef",
@@ -232,29 +177,15 @@ CreateManagedEndpointResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateVirtualClusterRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateVirtualClusterRequestRequestTypeDef",
+CreateVirtualClusterRequestRequestTypeDef = TypedDict(
+    "CreateVirtualClusterRequestRequestTypeDef",
     {
         "name": str,
         "containerProvider": "ContainerProviderTypeDef",
         "clientToken": str,
+        "tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalCreateVirtualClusterRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateVirtualClusterRequestRequestTypeDef",
-    {
-        "tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateVirtualClusterRequestRequestTypeDef(
-    _RequiredCreateVirtualClusterRequestRequestTypeDef,
-    _OptionalCreateVirtualClusterRequestRequestTypeDef,
-):
-    pass
-
 
 CreateVirtualClusterResponseTypeDef = TypedDict(
     "CreateVirtualClusterResponseTypeDef",
@@ -348,118 +279,87 @@ DescribeVirtualClusterResponseTypeDef = TypedDict(
 EksInfoTypeDef = TypedDict(
     "EksInfoTypeDef",
     {
-        "namespace": str,
+        "namespace": NotRequired[str],
     },
-    total=False,
 )
 
 EndpointTypeDef = TypedDict(
     "EndpointTypeDef",
     {
-        "id": str,
-        "name": str,
-        "arn": str,
-        "virtualClusterId": str,
-        "type": str,
-        "state": EndpointStateType,
-        "releaseLabel": str,
-        "executionRoleArn": str,
-        "certificateArn": str,
-        "certificateAuthority": "CertificateTypeDef",
-        "configurationOverrides": "ConfigurationOverridesTypeDef",
-        "serverUrl": str,
-        "createdAt": datetime,
-        "securityGroup": str,
-        "subnetIds": List[str],
-        "stateDetails": str,
-        "failureReason": FailureReasonType,
-        "tags": Dict[str, str],
+        "id": NotRequired[str],
+        "name": NotRequired[str],
+        "arn": NotRequired[str],
+        "virtualClusterId": NotRequired[str],
+        "type": NotRequired[str],
+        "state": NotRequired[EndpointStateType],
+        "releaseLabel": NotRequired[str],
+        "executionRoleArn": NotRequired[str],
+        "certificateArn": NotRequired[str],
+        "certificateAuthority": NotRequired["CertificateTypeDef"],
+        "configurationOverrides": NotRequired["ConfigurationOverridesTypeDef"],
+        "serverUrl": NotRequired[str],
+        "createdAt": NotRequired[datetime],
+        "securityGroup": NotRequired[str],
+        "subnetIds": NotRequired[List[str]],
+        "stateDetails": NotRequired[str],
+        "failureReason": NotRequired[FailureReasonType],
+        "tags": NotRequired[Dict[str, str]],
     },
-    total=False,
 )
 
 JobDriverTypeDef = TypedDict(
     "JobDriverTypeDef",
     {
-        "sparkSubmitJobDriver": "SparkSubmitJobDriverTypeDef",
+        "sparkSubmitJobDriver": NotRequired["SparkSubmitJobDriverTypeDef"],
     },
-    total=False,
 )
 
 JobRunTypeDef = TypedDict(
     "JobRunTypeDef",
     {
-        "id": str,
-        "name": str,
-        "virtualClusterId": str,
-        "arn": str,
-        "state": JobRunStateType,
-        "clientToken": str,
-        "executionRoleArn": str,
-        "releaseLabel": str,
-        "configurationOverrides": "ConfigurationOverridesTypeDef",
-        "jobDriver": "JobDriverTypeDef",
-        "createdAt": datetime,
-        "createdBy": str,
-        "finishedAt": datetime,
-        "stateDetails": str,
-        "failureReason": FailureReasonType,
-        "tags": Dict[str, str],
+        "id": NotRequired[str],
+        "name": NotRequired[str],
+        "virtualClusterId": NotRequired[str],
+        "arn": NotRequired[str],
+        "state": NotRequired[JobRunStateType],
+        "clientToken": NotRequired[str],
+        "executionRoleArn": NotRequired[str],
+        "releaseLabel": NotRequired[str],
+        "configurationOverrides": NotRequired["ConfigurationOverridesTypeDef"],
+        "jobDriver": NotRequired["JobDriverTypeDef"],
+        "createdAt": NotRequired[datetime],
+        "createdBy": NotRequired[str],
+        "finishedAt": NotRequired[datetime],
+        "stateDetails": NotRequired[str],
+        "failureReason": NotRequired[FailureReasonType],
+        "tags": NotRequired[Dict[str, str]],
     },
-    total=False,
 )
 
-_RequiredListJobRunsRequestListJobRunsPaginateTypeDef = TypedDict(
-    "_RequiredListJobRunsRequestListJobRunsPaginateTypeDef",
+ListJobRunsRequestListJobRunsPaginateTypeDef = TypedDict(
+    "ListJobRunsRequestListJobRunsPaginateTypeDef",
     {
         "virtualClusterId": str,
+        "createdBefore": NotRequired[Union[datetime, str]],
+        "createdAfter": NotRequired[Union[datetime, str]],
+        "name": NotRequired[str],
+        "states": NotRequired[Sequence[JobRunStateType]],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
-_OptionalListJobRunsRequestListJobRunsPaginateTypeDef = TypedDict(
-    "_OptionalListJobRunsRequestListJobRunsPaginateTypeDef",
-    {
-        "createdBefore": Union[datetime, str],
-        "createdAfter": Union[datetime, str],
-        "name": str,
-        "states": Sequence[JobRunStateType],
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
 
-
-class ListJobRunsRequestListJobRunsPaginateTypeDef(
-    _RequiredListJobRunsRequestListJobRunsPaginateTypeDef,
-    _OptionalListJobRunsRequestListJobRunsPaginateTypeDef,
-):
-    pass
-
-
-_RequiredListJobRunsRequestRequestTypeDef = TypedDict(
-    "_RequiredListJobRunsRequestRequestTypeDef",
+ListJobRunsRequestRequestTypeDef = TypedDict(
+    "ListJobRunsRequestRequestTypeDef",
     {
         "virtualClusterId": str,
+        "createdBefore": NotRequired[Union[datetime, str]],
+        "createdAfter": NotRequired[Union[datetime, str]],
+        "name": NotRequired[str],
+        "states": NotRequired[Sequence[JobRunStateType]],
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
 )
-_OptionalListJobRunsRequestRequestTypeDef = TypedDict(
-    "_OptionalListJobRunsRequestRequestTypeDef",
-    {
-        "createdBefore": Union[datetime, str],
-        "createdAfter": Union[datetime, str],
-        "name": str,
-        "states": Sequence[JobRunStateType],
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class ListJobRunsRequestRequestTypeDef(
-    _RequiredListJobRunsRequestRequestTypeDef, _OptionalListJobRunsRequestRequestTypeDef
-):
-    pass
-
 
 ListJobRunsResponseTypeDef = TypedDict(
     "ListJobRunsResponseTypeDef",
@@ -470,58 +370,30 @@ ListJobRunsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef = TypedDict(
-    "_RequiredListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef",
+ListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef = TypedDict(
+    "ListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef",
     {
         "virtualClusterId": str,
+        "createdBefore": NotRequired[Union[datetime, str]],
+        "createdAfter": NotRequired[Union[datetime, str]],
+        "types": NotRequired[Sequence[str]],
+        "states": NotRequired[Sequence[EndpointStateType]],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
-_OptionalListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef = TypedDict(
-    "_OptionalListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef",
-    {
-        "createdBefore": Union[datetime, str],
-        "createdAfter": Union[datetime, str],
-        "types": Sequence[str],
-        "states": Sequence[EndpointStateType],
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
 
-
-class ListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef(
-    _RequiredListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef,
-    _OptionalListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef,
-):
-    pass
-
-
-_RequiredListManagedEndpointsRequestRequestTypeDef = TypedDict(
-    "_RequiredListManagedEndpointsRequestRequestTypeDef",
+ListManagedEndpointsRequestRequestTypeDef = TypedDict(
+    "ListManagedEndpointsRequestRequestTypeDef",
     {
         "virtualClusterId": str,
+        "createdBefore": NotRequired[Union[datetime, str]],
+        "createdAfter": NotRequired[Union[datetime, str]],
+        "types": NotRequired[Sequence[str]],
+        "states": NotRequired[Sequence[EndpointStateType]],
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
 )
-_OptionalListManagedEndpointsRequestRequestTypeDef = TypedDict(
-    "_OptionalListManagedEndpointsRequestRequestTypeDef",
-    {
-        "createdBefore": Union[datetime, str],
-        "createdAfter": Union[datetime, str],
-        "types": Sequence[str],
-        "states": Sequence[EndpointStateType],
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class ListManagedEndpointsRequestRequestTypeDef(
-    _RequiredListManagedEndpointsRequestRequestTypeDef,
-    _OptionalListManagedEndpointsRequestRequestTypeDef,
-):
-    pass
-
 
 ListManagedEndpointsResponseTypeDef = TypedDict(
     "ListManagedEndpointsResponseTypeDef",
@@ -550,28 +422,26 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 ListVirtualClustersRequestListVirtualClustersPaginateTypeDef = TypedDict(
     "ListVirtualClustersRequestListVirtualClustersPaginateTypeDef",
     {
-        "containerProviderId": str,
-        "containerProviderType": Literal["EKS"],
-        "createdAfter": Union[datetime, str],
-        "createdBefore": Union[datetime, str],
-        "states": Sequence[VirtualClusterStateType],
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "containerProviderId": NotRequired[str],
+        "containerProviderType": NotRequired[Literal["EKS"]],
+        "createdAfter": NotRequired[Union[datetime, str]],
+        "createdBefore": NotRequired[Union[datetime, str]],
+        "states": NotRequired[Sequence[VirtualClusterStateType]],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
-    total=False,
 )
 
 ListVirtualClustersRequestRequestTypeDef = TypedDict(
     "ListVirtualClustersRequestRequestTypeDef",
     {
-        "containerProviderId": str,
-        "containerProviderType": Literal["EKS"],
-        "createdAfter": Union[datetime, str],
-        "createdBefore": Union[datetime, str],
-        "states": Sequence[VirtualClusterStateType],
-        "maxResults": int,
-        "nextToken": str,
+        "containerProviderId": NotRequired[str],
+        "containerProviderType": NotRequired[Literal["EKS"]],
+        "createdAfter": NotRequired[Union[datetime, str]],
+        "createdBefore": NotRequired[Union[datetime, str]],
+        "states": NotRequired[Sequence[VirtualClusterStateType]],
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListVirtualClustersResponseTypeDef = TypedDict(
@@ -586,21 +456,21 @@ ListVirtualClustersResponseTypeDef = TypedDict(
 MonitoringConfigurationTypeDef = TypedDict(
     "MonitoringConfigurationTypeDef",
     {
-        "persistentAppUI": PersistentAppUIType,
-        "cloudWatchMonitoringConfiguration": "CloudWatchMonitoringConfigurationTypeDef",
-        "s3MonitoringConfiguration": "S3MonitoringConfigurationTypeDef",
+        "persistentAppUI": NotRequired[PersistentAppUIType],
+        "cloudWatchMonitoringConfiguration": NotRequired[
+            "CloudWatchMonitoringConfigurationTypeDef"
+        ],
+        "s3MonitoringConfiguration": NotRequired["S3MonitoringConfigurationTypeDef"],
     },
-    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -621,54 +491,28 @@ S3MonitoringConfigurationTypeDef = TypedDict(
     },
 )
 
-_RequiredSparkSubmitJobDriverTypeDef = TypedDict(
-    "_RequiredSparkSubmitJobDriverTypeDef",
+SparkSubmitJobDriverTypeDef = TypedDict(
+    "SparkSubmitJobDriverTypeDef",
     {
         "entryPoint": str,
+        "entryPointArguments": NotRequired[List[str]],
+        "sparkSubmitParameters": NotRequired[str],
     },
 )
-_OptionalSparkSubmitJobDriverTypeDef = TypedDict(
-    "_OptionalSparkSubmitJobDriverTypeDef",
-    {
-        "entryPointArguments": List[str],
-        "sparkSubmitParameters": str,
-    },
-    total=False,
-)
 
-
-class SparkSubmitJobDriverTypeDef(
-    _RequiredSparkSubmitJobDriverTypeDef, _OptionalSparkSubmitJobDriverTypeDef
-):
-    pass
-
-
-_RequiredStartJobRunRequestRequestTypeDef = TypedDict(
-    "_RequiredStartJobRunRequestRequestTypeDef",
+StartJobRunRequestRequestTypeDef = TypedDict(
+    "StartJobRunRequestRequestTypeDef",
     {
         "virtualClusterId": str,
         "clientToken": str,
         "executionRoleArn": str,
         "releaseLabel": str,
         "jobDriver": "JobDriverTypeDef",
+        "name": NotRequired[str],
+        "configurationOverrides": NotRequired["ConfigurationOverridesTypeDef"],
+        "tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalStartJobRunRequestRequestTypeDef = TypedDict(
-    "_OptionalStartJobRunRequestRequestTypeDef",
-    {
-        "name": str,
-        "configurationOverrides": "ConfigurationOverridesTypeDef",
-        "tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class StartJobRunRequestRequestTypeDef(
-    _RequiredStartJobRunRequestRequestTypeDef, _OptionalStartJobRunRequestRequestTypeDef
-):
-    pass
-
 
 StartJobRunResponseTypeDef = TypedDict(
     "StartJobRunResponseTypeDef",
@@ -700,13 +544,12 @@ UntagResourceRequestRequestTypeDef = TypedDict(
 VirtualClusterTypeDef = TypedDict(
     "VirtualClusterTypeDef",
     {
-        "id": str,
-        "name": str,
-        "arn": str,
-        "state": VirtualClusterStateType,
-        "containerProvider": "ContainerProviderTypeDef",
-        "createdAt": datetime,
-        "tags": Dict[str, str],
+        "id": NotRequired[str],
+        "name": NotRequired[str],
+        "arn": NotRequired[str],
+        "state": NotRequired[VirtualClusterStateType],
+        "containerProvider": NotRequired["ContainerProviderTypeDef"],
+        "createdAt": NotRequired[datetime],
+        "tags": NotRequired[Dict[str, str]],
     },
-    total=False,
 )
